@@ -1,153 +1,16 @@
 package HTML::Auto;
+# ABSTRACT: automatic write HTML for common elements
 
 use warnings;
 use strict;
 
 use Template;
 use HTML::Auto::Templates;
-use Data::Dumper;
 
 require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(matrix h v);
 
-=encoding utf-8
-
-=head1 NAME
-
-HTML::Auto - automatic write HTML for common elements
-
-=head1 VERSION
-
-Version 0.07
-
-=cut
-
-our $VERSION = '0.07';
-
-
-=head1 SYNOPSIS
-
-Simple example:
-
-  use HTML::Auto qw/matrix h v/;
-
-  my @cols = qw/c1 c2 c3 c4 c5/;
-  my @lines = qw/l1 l2 l3 l4 l5/;
-  my $data =
-     [ [1,2,3,4,5],
-       [6,7,8,9,0],
-       [1,1,1,1,1],
-       [2,2,2,2,2],
-       [3,3,3,3,3] ];
-
-  my $m = matrix(\@cols,\@lines,$data);
-
-  print v(
-          h($m,$m,$m),
-          h($m,$m),
-        );
-
-Using attributes:
-
-  use HTML::Auto qw/matrix h v/;
-
-  my @cols = qw/c1 c2/;
-  my @lines = qw/l1 l2/;
-  my $data =
-     [
-       [
-         {v => 1, a => { style => 'background: green'}},
-         2
-       ],
-       [
-         {v => 3, a => {class => 'foo'}},
-         {v => 4, a => {style => 'color: red'}}
-       ]
-     ];
-
-  my $m = matrix(\@cols,\@lines,$data);
-
-  print v(
-          h($m)
-        );
-
-With mouse-over span:
-
-  use HTML::Auto qw/matrix h v/;
-
-  my @cols = qw/c1 c2/;
-  my @lines = qw/l1 l2/;
-  my $data =
-     [[1,2],
-	  [3,
-	  { v=> 4,
-	    more_info => "This is a pop-up!"
-	  }]
-	 ];
-
-
-  my $m = matrix(\@cols,\@lines,$data);
-
-  print v(
-          h($m)
-        );
-
-Passing additional CSS:
-
-  use HTML::Auto qw/matrix h v/;
-
-  my @cols = qw/c1 c2/;
-  my @lines = qw/l1 l2/;
-  my $data =
-     [
-       [
-         {v => 1, a => { class => 'warn'}},
-         2
-       ],
-       [3,4]
-     ];
-
-  my $options = { css => '.warn { background-color: yellow !important; }' };
-
-  my $m = matrix(\@cols,\@lines,$data,$options);
-
-  print v(
-          h($m)
-        );
-
-
- 
-=head1 FUNCTIONS
-
-=head2 matrix
-
-Build a matrix. Some options are available to pass to the matrix function:
-
-=over 6
-
-=item C<diagonal>
-
-Highlight the diagonal of the matrix.
-
-  my $m = matrix(\@cols,\@lines,$data, {diagonal => 1});
-
-=item C<format>
-
-Pass a string to be used by the C<format> filter in the TT2 template.
-
-  my $m = matrix(\@cols,\@lines,$data, {format => '%.6f'});
-
-=item C<ucfirst>
-
-Option to uppercase first letter in columns and lines labels.
-
-  my $m = matrix(\@cols,\@lines,$data, {ucfirst => 1});
-
-=back
-
-=cut
-
 sub matrix {
 	my ($cols,$lines,$data,$options) = @_;
 
@@ -203,12 +66,6 @@ sub matrix {
 	__process($template_name, $vars);
 }
 
-=head2 h
-
-A function to allow horizontal composition.
-
-=cut
-
 sub h {
 	my (@list) = @_;
 
@@ -220,12 +77,6 @@ sub h {
 	__process($template_name, $vars);
 }
 
-=head2 v
-
-A function to allow vertical composition.
-
-=cut
-
 sub v {
    my (@list) = @_;
 
@@ -253,64 +104,167 @@ sub __process {
 	$html;
 }
 
-=head1 AUTHOR
+1;
 
-Nuno Carvalho, C<< <smash at cpan.org> >>
-André Santos, C<< <andrefs at cpan.org> >>
+__END__
 
-=head1 BUGS
+=pod
 
-Please report any bugs or feature requests to C<bug-html-auto at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=HTML-Auto>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
+=encoding utf-8
+
+=head1 NAME
+
+HTML::Auto - automatic write HTML for common elements
+
+=head1 VERSION
+
+version 0.08
+
+=head1 SYNOPSIS
+
+Simple example:
+
+  use HTML::Auto qw/matrix h v/;
+
+  my @cols = qw/c1 c2 c3 c4 c5/;
+  my @lines = qw/l1 l2 l3 l4 l5/;
+  my $data =
+     [ [1,2,3,4,5],
+       [6,7,8,9,0],
+       [1,1,1,1,1],
+       [2,2,2,2,2],
+       [3,3,3,3,3] ];
+
+  my $m = matrix(\@cols,\@lines,$data);
+
+  print v(
+          h($m,$m,$m),
+          h($m,$m),
+        );
+
+Using attributes:
+
+  use HTML::Auto qw/matrix h v/;
+
+  my @cols = qw/c1 c2/;
+  my @lines = qw/l1 l2/;
+  my $data =
+     [
+       [
+         {v => 1, a => { style => 'background: green'}},
+         2
+       ],
+       [
+         {v => 3, a => {class => 'foo'}},
+         {v => 4, a => {style => 'color: red'}}
+       ]
+     ];
+
+  my $m = matrix(\@cols,\@lines,$data);
+
+  print v(
+          h($m)
+        );
+
+With mouse-over span:
+
+  use HTML::Auto qw/matrix h v/;
+
+  my @cols = qw/c1 c2/;
+  my @lines = qw/l1 l2/;
+  my $data =
+     [[1,2],
+    [3,
+    { v=> 4,
+      more_info => "This is a pop-up!"
+    }]
+   ];
 
 
+  my $m = matrix(\@cols,\@lines,$data);
 
+  print v(
+          h($m)
+        );
 
-=head1 SUPPORT
+Passing additional CSS:
 
-You can find documentation for this module with the perldoc command.
+  use HTML::Auto qw/matrix h v/;
 
-    perldoc HTML::Auto
+  my @cols = qw/c1 c2/;
+  my @lines = qw/l1 l2/;
+  my $data =
+     [
+       [
+         {v => 1, a => { class => 'warn'}},
+         2
+       ],
+       [3,4]
+     ];
 
+  my $options = { css => '.warn { background-color: yellow !important; }' };
 
-You can also look for information at:
+  my $m = matrix(\@cols,\@lines,$data,$options);
 
-=over 4
+  print v(
+          h($m)
+        );
 
-=item * RT: CPAN's request tracker
+=head1 FUNCTIONS
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=HTML-Auto>
+=head2 matrix
 
-=item * AnnoCPAN: Annotated CPAN documentation
+Build a matrix. Some options are available to pass to the matrix function:
 
-L<http://annocpan.org/dist/HTML-Auto>
+=over 6
 
-=item * CPAN Ratings
+=item C<diagonal>
 
-L<http://cpanratings.perl.org/d/HTML-Auto>
+Highlight the diagonal of the matrix.
 
-=item * Search CPAN
+  my $m = matrix(\@cols,\@lines,$data, {diagonal => 1});
 
-L<http://search.cpan.org/dist/HTML-Auto/>
+=item C<format>
+
+Pass a string to be used by the C<format> filter in the TT2 template.
+
+  my $m = matrix(\@cols,\@lines,$data, {format => '%.6f'});
+
+=item C<ucfirst>
+
+Option to uppercase first letter in columns and lines labels.
+
+  my $m = matrix(\@cols,\@lines,$data, {ucfirst => 1});
 
 =back
 
+=head2 h
 
-=head1 ACKNOWLEDGEMENTS
+A function to allow horizontal composition.
 
+=head2 v
 
-=head1 LICENSE AND COPYRIGHT
+A function to allow vertical composition.
 
-Copyright 2012 Project Natura.
+=head1 AUTHORS
 
-This program is free software; you can redistribute it and/or modify it
-under the terms of either: the GNU General Public License as published
-by the Free Software Foundation; or the Artistic License.
+=over 4
 
-See http://dev.perl.org/licenses/ for more information.
+=item *
 
+Nuno Carvalho <smash@cpan.org>
+
+=item *
+
+André Santos <andrefs at cpan.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012-2016 by Project Natura <natura@natura.di.uminho.pt>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1; # End of HTML::Auto
